@@ -1,10 +1,13 @@
 class FramesetArgument(object):
 
-    __argumentType: str
+    __argument_type: str
     __definition: str
     __function: str
 
-    def __init__(self, argumentType: str, definition: str, function: str = None):
+    def __init__(self,
+                 argumentType: str,
+                 definition: str,
+                 function: str = None):
         """
         A constructor of FramesetArgument class which takes argumentType and definition as input and initializes
         corresponding attributes
@@ -18,7 +21,7 @@ class FramesetArgument(object):
         function : str
             Function of the frameset argument
         """
-        self.__argumentType = argumentType
+        self.__argument_type = argumentType
         self.__definition = definition
         self.__function = function
 
@@ -31,7 +34,7 @@ class FramesetArgument(object):
         str
             argumentType.
         """
-        return self.__argumentType
+        return self.__argument_type
 
     def getDefinition(self) -> str:
         """
@@ -87,4 +90,4 @@ class FramesetArgument(object):
         str
             string form of frameset argument
         """
-        return self.__argumentType + ":" + self.__definition
+        return self.__argument_type + ":" + self.__definition
